@@ -73,7 +73,7 @@ def test_wheel_module() -> None:
         assert "module1.py" in z.namelist()
 
 
-@pytest.mark.parametrize("project", ["complete", "complete_new"])
+@pytest.mark.parametrize("project", ["complete", "complete_new", "complete_dynamic"])
 def test_wheel_package(project: str) -> None:
     module_path = fixtures_dir / project
     WheelBuilder.make(Factory().create_poetry(module_path))
@@ -126,6 +126,23 @@ def test_wheel_epoch() -> None:
         assert "epoch-1!2.0.dist-info/METADATA" in z.namelist()
 
 
+def test_wheel_does_not_include_pycache_and_pyc_files(
+    complete_with_pycache_and_pyc_files: Path,
+) -> None:
+    WheelBuilder.make_in(Factory().create_poetry(complete_with_pycache_and_pyc_files))
+
+    whl = (
+        complete_with_pycache_and_pyc_files / "dist"
+    ) / "my_package-1.2.3-py3-none-any.whl"
+
+    assert whl.exists()
+
+    with zipfile.ZipFile(str(whl)) as z:
+        for name in z.namelist():
+            assert "__pycache__" not in name
+            assert not name.endswith(".pyc")
+
+
 def test_wheel_excluded_data() -> None:
     module_path = fixtures_dir / "default_with_excluded_data_toml"
     WheelBuilder.make(Factory().create_poetry(module_path))
@@ -231,7 +248,7 @@ def test_wheel_build_script_creates_package() -> None:
     shutil.rmtree(module_path / "my_package")
 
 
-@pytest.mark.parametrize("project", ["complete", "complete_new"])
+@pytest.mark.parametrize("project", ["complete", "complete_new", "complete_dynamic"])
 def test_dist_info_file_permissions(project: str) -> None:
     module_path = fixtures_dir / project
     WheelBuilder.make(Factory().create_poetry(module_path))
@@ -339,21 +356,44 @@ def test_wheel_package_pep_561_stub_only_includes_typed_marker() -> None:
         assert "pkg-stubs/py.typed" in z.namelist()
 
 
-def test_wheel_includes_licenses_in_correct_paths() -> None:
-    root = fixtures_dir / "licenses_and_copying"
+@pytest.mark.parametrize(
+    ("license_files", "expected"),
+    [
+        (
+            None,
+            [
+                "COPYING",
+                "COPYING.txt",
+                "LICENSE",
+                "LICENSE.md",
+                "LICENSES/CUSTOM-LICENSE",
+                "LICENSES/BSD-3.md",
+                "LICENSES/MIT.txt",
+            ],
+        ),
+        (["COPYING*", "LICENSE"], ["COPYING", "COPYING.txt", "LICENSE"]),
+        ([], []),
+    ],
+)
+def test_wheel_includes_licenses_in_correct_paths(
+    tmp_path: Path, license_files: list[str] | None, expected: list[str]
+) -> None:
+    root = tmp_path / "licenses_and_copying"
+    shutil.copytree(fixtures_dir / "licenses_and_copying", root)
+    if license_files is not None:
+        pyproject_path = root / "pyproject.toml"
+        pyproject_content = pyproject_path.read_text(encoding="utf-8")
+        pyproject_content += f"\nlicense-files = {license_files}"
+        pyproject_path.write_text(pyproject_content, encoding="utf-8")
+
     WheelBuilder.make(Factory().create_poetry(root))
 
     whl = root / "dist" / "my_package-1.2.3-py3-none-any.whl"
-
+    licenses_path = "my_package-1.2.3.dist-info/licenses"
     assert whl.exists()
     with zipfile.ZipFile(str(whl)) as z:
-        assert "my_package-1.2.3.dist-info/COPYING" in z.namelist()
-        assert "my_package-1.2.3.dist-info/COPYING.txt" in z.namelist()
-        assert "my_package-1.2.3.dist-info/LICENSE" in z.namelist()
-        assert "my_package-1.2.3.dist-info/LICENSE.md" in z.namelist()
-        assert "my_package-1.2.3.dist-info/LICENSES/CUSTOM-LICENSE" in z.namelist()
-        assert "my_package-1.2.3.dist-info/LICENSES/BSD-3.md" in z.namelist()
-        assert "my_package-1.2.3.dist-info/LICENSES/MIT.txt" in z.namelist()
+        licenses_content = {p for p in z.namelist() if p.startswith(licenses_path)}
+    assert licenses_content == {f"{licenses_path}/{p}" for p in expected}
 
 
 def test_wheel_with_file_with_comma() -> None:
